@@ -1,5 +1,7 @@
-"""Manage compley chains of transformations."""
-import warnings
+"""Manage complex chains of transformations.
+
+See :doc:`transform_manager` for more information.
+"""
 import numpy as np
 import scipy.sparse as sp
 from scipy.sparse import csgraph
@@ -14,26 +16,27 @@ from .plot_utils import make_3d_axis
 
 
 class TransformManager(object):
-    """Manage transforms between frames.
+    """Manage transformations between frames.
 
     This is a simplified version of `ROS tf <http://wiki.ros.org/tf>`_ that
-    ignores the temporal aspect. A user can register transforms. The shortest
-    path between all frames will be computed internally which enables us to
-    provide transforms for any connected frames.
+    ignores the temporal aspect. A user can register transformations. The
+    shortest path between all frames will be computed internally which enables
+    us to provide transforms for any connected frames.
 
-    Suppose we know the transforms A2B, D2C, and B2C. The transform manager can
-    compute any transform between the frames A, B, C and D. For example, you
-    can request the transform that represents frame D in frame A. The transform
-    manager will automatically concatenate the transform D2C, C2B, and B2A,
-    where C2B and B2A are obtained by inverting B2C and A2B respectively.
+    Suppose we know the transformations A2B, D2C, and B2C. The transform
+    manager can compute any transformation between the frames A, B, C and D.
+    For example, you can request the transformation that represents frame D in
+    frame A. The transformation manager will automatically concatenate the
+    transformations D2C, C2B, and B2A, where C2B and B2A are obtained by
+    inverting B2C and A2B respectively.
 
     .. warning::
 
-        It is possible to introduce inconsistencies in the transform manager.
-        Adding A2B and B2A with inconsistent values will result in an invalid
-        state because inconsistencies will not be checked. It seems to be
-        trivial in this simple case but can be computationally complex for
-        large graphs. You can check the consistency explicitly with
+        It is possible to introduce inconsistencies in the transformation
+        manager. Adding A2B and B2A with inconsistent values will result in
+        an invalid state because inconsistencies will not be checked. It seems
+        to be trivial in this simple case but can be computationally complex
+        for large graphs. You can check the consistency explicitly with
         :func:`TransformManager.check_consistency`.
 
     Parameters
@@ -53,28 +56,38 @@ class TransformManager(object):
 
         self.transforms = {}
         self.nodes = []
+
+        # A pair (self.i[n], self.j[n]) represents indices of connected nodes
         self.i = []
         self.j = []
+        # We have to store the index n associated to a transformation to be
+        # able to remove the transformation later
+        self.transform_to_ij_index = {}
+        # Same information as sparse matrix
         self.connections = sp.csr_matrix((0, 0))
+
+        # Result of shortest path algorithm:
+        # distance matrix (distance is the number of transformations)
         self.dist = None
         self.predecessors = None
+
         self._cached_shortest_paths = {}
 
     def add_transform(self, from_frame, to_frame, A2B):
-        """Register a transform.
+        """Register a transformation.
 
         Parameters
         ----------
         from_frame : str
-            Name of the frame for which the transform is added in the to_frame
-            coordinate system
+            Name of the frame for which the transformation is added in the
+            to_frame coordinate system
 
         to_frame : str
-            Name of the frame in which the transform is defined
+            Name of the frame in which the transformation is defined
 
         A2B : array-like, shape (4, 4)
-            Homogeneous matrix that represents the transform from 'from_frame'
-            to 'to_frame'
+            Homogeneous matrix that represents the transformation from
+            'from_frame' to 'to_frame'
 
         Returns
         -------
@@ -88,19 +101,52 @@ class TransformManager(object):
         if to_frame not in self.nodes:
             self.nodes.append(to_frame)
 
+        transform_key = (from_frame, to_frame)
+
         recompute_shortest_path = False
-        if (from_frame, to_frame) not in self.transforms:
+        if transform_key not in self.transforms:
+            ij_index = len(self.i)
             self.i.append(self.nodes.index(from_frame))
             self.j.append(self.nodes.index(to_frame))
+            self.transform_to_ij_index[transform_key] = ij_index
             recompute_shortest_path = True
 
-        self.transforms[(from_frame, to_frame)] = A2B
+        self.transforms[transform_key] = A2B
 
         if recompute_shortest_path:
             self._recompute_shortest_path()
 
         return self
 
+    def remove_transform(self, from_frame, to_frame):
+        """Remove a transformation.
+
+        Nothing happens if there is no such transformation.
+
+        Parameters
+        ----------
+        from_frame : str
+            Name of the frame for which the transformation is added in the
+            to_frame coordinate system
+
+        to_frame : str
+            Name of the frame in which the transformation is defined
+
+        Returns
+        -------
+        self : TransformManager
+            This object for chaining
+        """
+        transform_key = (from_frame, to_frame)
+        if transform_key in self.transforms:
+            del self.transforms[transform_key]
+            ij_index = self.transform_to_ij_index[transform_key]
+            del self.transform_to_ij_index[transform_key]
+            del self.i[ij_index]
+            del self.j[ij_index]
+            self._recompute_shortest_path()
+        return self
+
     def _recompute_shortest_path(self):
         n_nodes = len(self.nodes)
         self.connections = sp.csr_matrix(
@@ -127,22 +173,22 @@ class TransformManager(object):
         return frame in self.nodes
 
     def get_transform(self, from_frame, to_frame):
-        """Request a transform.
+        """Request a transformation.
 
         Parameters
         ----------
         from_frame : str
-            Name of the frame for which the transform is requested in the
+            Name of the frame for which the transformation is requested in the
             to_frame coordinate system
 
         to_frame : str
-            Name of the frame in which the transform is defined
+            Name of the frame in which the transformation is defined
 
         Returns
         -------
         A2B : array-like, shape (4, 4)
-            Homogeneous matrix that represents the transform from 'from_frame'
-            to 'to_frame'
+            Homogeneous matrix that represents the transformation from
+            'from_frame' to 'to_frame'
         """
         if self.check:
             if from_frame not in self.nodes:
@@ -240,7 +286,7 @@ class TransformManager(object):
 
         A line between each pair of frames for which a direct transformation
         is known will be plotted. Direct means that either A2B or B2A has been
-        added to the transform manager.
+        added to the transformation manager.
 
         Note that frames that cannot be connected to the reference frame are
         omitted.
